Dictionary

Struct Dictionary 

pub struct Dictionary {
    pub language: String,
    /* private fields */
}
Cifra stores word dictionaries in a local database. This class is a wrapper to not to deal directly with that database.

This class is intended to be used as a context manager so you don’t have to deal with opening and closing this dictionary. So, call this method as a context manager, it will return this instance so you can call further methods to manage its words.

Fields

language: String

Implementations

Source

impl Dictionary

pub fn remove_dictionary<T>(_language: T) -> Result<()>
where T: AsRef<str>,

Remove given language from database.

Be aware that all its words will be removed too.

Parameters:
  • language: Language to remove from database.
pub fn get_dictionaries_names() -> Result<Vec<String>>

Get languages dictionaries present at database.

Returns:
  • A list with names of dictionaries present at database.
pub fn new<T>(_language: T, create: bool) -> Result<Self>
where T: AsRef<str>,

Parameters:
  • language: Language you want to manage its words.
  • create: Whether this language should be created in database if not present yet. It defaults to False. If it is set to False and language is not already present at database then a dictionaries.NotExistingLanguage exception is raised, but if it is set to True then language is registered in database as a new language.
pub fn session(&self) -> &DatabaseSession

Get open session for current dictionary database.

pub fn add_word<T>(&mut self, _word: T)
where T: AsRef<str>,

Add given word to dictionary.

If word is already present at dictionary, do nothing.

Parameters:
  • word: word to add to dictionary.
pub fn add_multiple_words(&mut self, _words: &HashSet<String>)

Add given words to dictionary.

Parameters:
  • words: Set of words to add to dictionary.
pub fn remove_word<T>(&mut self, _word: T)
where T: AsRef<str>,

Remove given word from dictionary.

If word is not already present at dictionary, do nothing.

Parameters:
  • word: word to remove from dictionary.
pub fn word_exists<T>(&self, _word: T) -> bool
where T: AsRef<str>,

Check if given word exists at this dictionary.

Parameters:
  • word: word to check.
Returns:

True if word is already present at dictionary, False otherwise.

pub fn populate<T>(&mut self, file_pathname: T) -> Result<()>
where T: AsRef<Path>,

Read a file’s words and stores them at this language database.

Parameters:
  • file_pathname: Absolute path to file with text to analyze.
pub fn get_words_with_pattern<T>(&self, pattern: T) -> Result<Vec<String>>
where T: AsRef<str>,

Get a list of every word with given pattern.

Parameters:
  • pattern: Word patter to search for.
Returns:
  • List of words at dictionary with given pattern.
pub fn get_words_presence(&self, _words: &HashSet<String>) -> f64

Get how many words of given set are really present in this dictionary.

Parameters:
  • words: Set of words.
Returns:
  • A float between 0 and 1 being 1 as every word in set is present at dictionary.
pub fn get_all_words(&self) -> Result<Vec<String>>

Get a list of every word present at dictionary.