pub struct Parameters { /* private fields */ }Expand description
Whereas Python offers variable arguments for its functions, Rust does not. The only way I’ve found to use variable arguments with function pointers is pass parameters stored in a single HashMap.
This type use a HashMap to store both usize parameters and string ones.
Implementations